#!/bin/sh
set +x
########################################################################################################################################################
# Script Version# - Version 1.0
# Parent script to invoke the below listed scripts. Scripts / commands are listed below:
# 1) preRequisites.sh
#    Script functionality below:
#     - Check Network Connectivity and other validations for required inputs.(Fail if anything is missing).
#     - Copy connector into Host System.
#     - Install Connector.
#     - Install/Start ISCSI service if Needed.
# 2) Execute the maxdbConfig.sh script.
#     - This will give data to be used while creating the generic app and log volumes.
# 3) ApplianceOperations.sh
#    Script functionality below:
#     - Add Host.
#     - Enable CBT.
#     - Discover Apps on Actifio Appliance.
#     - Protect DB and LOG on Actifio Appliance.
#     - Protect other FS on Actifio Appliance.
########################################################################################################################################################

#set -x
if [ "$#" -lt 1 ]; then
  echo " This script needs key-value input parameters"
  echo " usage: backupAutomation.sh <name=value>"
  echo " For example: backupAutomation.sh OSUSER=sapdb"
  exit 1
fi

# Check if JQ and CURL is installed
if ! type "jq" > /dev/null 2>&1; then
  echo "Error : JQ is not installed"
  exit 1
fi

if ! type "curl" > /dev/null 2>&1; then
  echo "Error : curl is not installed"
  exit 1
fi

backupConfFile="/act/act_scripts/maxdb/automation/Configuration/maxdbbackup.conf"

echo -e '#maxdb DB/Logbackup Specific Params' > $backupConfFile
for ARGUMENT in "$@"
do
   ARGUMENT="${ARGUMENT%\"}"
   ARGUMENT="${ARGUMENT#\"}"
   passwdstrCheck=`echo $ARGUMENT | grep -i "password\|passwd"`
   if [ -z "$passwdstrCheck" ]; then
     echo -e $ARGUMENT >> $backupConfFile
   else
     export $ARGUMENT
   fi
done

echo -e '#Custom Policy Settings if template is not pre-created for DB and Log Templates' >> $backupConfFile
echo -e 'dbbackup_rpo="24"' >> $backupConfFile
echo -e 'logbackup_rpo="1"' >> $backupConfFile

echo -e '#Key used for Licensing purpose' >> $backupConfFile
echo -e 'VendorKey="act"' >> $backupConfFile
#echo -e '#Profile name used during backup' >> $backupConfFile

if ! grep -q "ProfileName"  "$backupConfFile"; then
 echo -e 'ProfileName="LocalProfile"' >> $backupConfFile
fi

source $backupConfFile


#Checking if all mandatory parameters are present.

if [ -z $LogBackupEnable ]; then
   echo " Error : LogBackupEnable cannot be empty."
   exit 1
fi

if [[ $LogBackupEnable == "true" ]]; then
  if [ -z $DELLOG ]; then
     echo " Error : DELLOG cannot be empty."
     exit 1
  fi
fi


if [ -z $SkyIP ]; then
   echo " Error : Sky IP cannot be empty."
   exit 1
fi

if [ -z $MaxdbTemplateName ]; then
   echo " Error : Template name cannot be empty."
   exit 1
fi

if [ -z $dbbackup_rpo ]; then
   echo " Error : DB Backup RPO cannot be empty."
   exit 1
fi

if [ -z $OSUSER ]; then
   echo " Error : OSUSER cannot be empty."
   exit 1
fi

if [ -z $SRC_MAXDB_DBMCLI_PATH ]; then
   echo " Error : MaxDB DBMCLI PATH cannot be empty."
   exit 1
fi

if [ -z $SRC_DBNAME_KEY_PREFIX ]; then
   echo " Error : DB UserKey cannot be empty."
   exit 1
fi

if [ -z $SRC_DBNAME ]; then
   echo " Error : DB name cannot be empty."
   exit 1
fi

if [ -z $BACKUP_TYPE ]; then
   BACKUP_TYPE="Filesystemdump"
fi

if [ -z $MAXDBBACKUPPATH ] && [ -z $GenericAppName ]; then
  echo " Error : Application Name cannot be empty."
  exit 1
fi

if [ -z $SkyPassword ]; then
  echo " Error : Sky Password cannot be empty."
  exit 1
fi

if [ -z $SRC_HOSTNAME ]; then
  SRC_HOSTNAME=`hostname`
fi

if [ "$BACKUP_TYPE" != "LVMSnapshot" ] && [ "$BACKUP_TYPE" != "Filesystemdump" ] ; then
    echo "Exiting!!!...Incorrect Backup Type $BACKUP_TYPE Expected Values are LVMSnapshot/Filesystemdump"
    exit 1
fi

if [ "$BACKUP_TYPE" == "LVMSnapshot" ]; then
  if [ -z $VgSnapReserveSpace ]; then
    echo " Error : Percentage of reserved space in Volume Group[ 1-100 desired 20] cannot be empty."
    exit 1
  fi
  if [ -z $GenericAppName ]; then
    echo " Error : Application Name cannot be empty."
    exit 1
  fi
fi

if [ "$BACKUP_TYPE" == "Filesystemdump" ]; then
  if [ -z $MAXDBBACKUPPATH ]; then
    echo " Error : MAXDBBACKUPPATH cannot be empty."
    exit 1
  fi
fi

tmp_loc=/act/touch
if [ ! -d $tmp_loc ]; then
 mkdir -p $tmp_loc
fi
chmod -R 777 /act

source /act/act_scripts/maxdb/automation/Backup/paramValueValidator.sh
validateDbParams
set +x
SkyUserName="admin"

echo "-----------------------------------------------------"
echo "-----Starting MaxDB Backup Configuration-------"
echo "-----------------------------------------------------"

# Step 1 : Invoking PreRequisites.sh script to check pre-requisites (UDSAgent and ISCSI service)
echo "----------------------------------------------------------"
echo "---Start Phase: Checking Pre-Requisites on Host machine---"
echo "----------------------------------------------------------"
source /act/act_scripts/maxdb/automation/Backup/preRequisites.sh $SkyIP

if [ "$BACKUP_TYPE" == "Filesystemdump" ]; then
  source /act/act_scripts/maxdb/automation/Backup/maxdbDumpConfig.sh
fi

echo "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"
echo "-----End Phase: Completed Checking Pre-Requisites-----"
echo "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"

iqnName=`grep iqn /etc/iscsi/initiatorname.iscsi | cut -d '=' -f 2`

# Step 3 : Invoking ApplianceOperations.sh script to perform Add host, Enable CBT and Discover apps. It would internally invoke CreateGenericApp.sh and LogProtection.sh

if [ -z $iqnName ]; then
   echo " Error : IQN Name is blank."
   exit 1
fi

source /act/act_scripts/maxdb/automation/Backup/applianceOperations.sh $iqnName

DisableMultipathCheck=true
grep -q '^DisableMultipathCheck.*' /act/config/connector.conf &&  sed -i 's/^DisableMultipathCheck.*/DisableMultipathCheck='"$DisableMultipathCheck"'/g' /act/config/connector.conf || echo -e 'DisableMultipathCheck='"$DisableMultipathCheck"'' >> /act/config/connector.conf

echo "------------------------------------------------------"
echo "----------Completed the Backup Configuration----------"
echo "------------------------------------------------------"
